=========
Reference
=========

.. toctree::

   cor_sort
   cor_sort_borda
   cor_sort_delegate
   cor_sort_gain
   cor_sort_gain_lexi
   distance_to_sorted_array
   entropy_bound
   jit_scorers
   jit_sorts
   merge
   montecarlo
   partition
   presets
   sort
   sort_asort_quickselect
   sort_ford_johnson
   sort_largest_interval
   sort_merge_bfs
   sort_merge_dfs
   sort_quick
   wrap_full_jit
   wrap_sort_scorer
